use sqlx::query_as;

use crate::types::{AppointmentSlot, AppointmentSlots, Subject, Subjects, Teacher, Teachers};

use super::Pool;

pub async fn get_teachers(db: &Pool) -> Result<Teachers, sqlx::Error> {
    query_as!(
        Teacher,
        r#"
        SELECT *
        FROM `teachers`"#,
    )
    .fetch_all(&*db)
    .await
}

pub async fn get_subjects(db: &Pool) -> Result<Subjects, sqlx::Error> {
    query_as!(
        Subject,
        r#"
        SELECT *
        FROM `subjects`"#,
    )
    .fetch_all(&*db)
    .await
}

pub async fn get_free_slots(db: &Pool) -> Result<AppointmentSlots, sqlx::Error> {
    match query_as!(
        AppointmentSlot,
        r#"
        SELECT *
        FROM `appointment_slots`"#,
    )
    .fetch_all(&*db)
    .await
    {
        Ok(elems) => Ok(elems.into_iter().map(|e| (e.id, e)).collect()),
        Err(e) => Err(e),
    }
}
